pub fn module_name_from_path(path: &Path) -> String
The module name implied by a source file path: its file stem, or module when the stem is not valid UTF-8. 源文件路径隐含的模块名:文件主干名;主干不是合法 UTF-8 时为 module。
module