pub fn function_symbols(source: &str) -> Vec<SourceFunction>Expand description
Index function bodies without treating comments, strings, or macro text as Rust. 扫描函数体时屏蔽注释、字符串和宏文本,避免把它们误认成 Rust 函数。
pub fn function_symbols(source: &str) -> Vec<SourceFunction>Index function bodies without treating comments, strings, or macro text as Rust. 扫描函数体时屏蔽注释、字符串和宏文本,避免把它们误认成 Rust 函数。