macro_rules! trace_transform {
($trace:expr, $input:expr, $name:literal, $type_name:literal, $value:expr) => { ... };
}Expand description
Capture a transformed value and connect it to its producer. 记录转换后的值,并把它连接到生产者。
macro_rules! trace_transform {
($trace:expr, $input:expr, $name:literal, $type_name:literal, $value:expr) => { ... };
}Capture a transformed value and connect it to its producer. 记录转换后的值,并把它连接到生产者。