CutGraftCommand

Struct CutGraftCommand 

pub struct CutGraftCommand {
    pub cut: String,
    pub end: Option<String>,
    pub graft: String,
    pub full: bool,
}
Parsed cut [A/a1/b2] graft replacement command. 解析 cut [A/a1/b2] graft replacement 命令。

Fields

cut: String

Start of the cut path or of a range. 切口路径或区间的起点。

end: Option<String>

Far endpoint when the command spelled a range. 命令写出区间时的远端终点。

graft: String

External implementation selector. 外部实现选择器。

full: bool

Whether the cut replaces the whole subtree. 该切口是否替换整棵子树。

Implementations

Source

impl CutGraftCommand

pub fn parse(command: &str) -> Result<CutGraftCommand, String>

Parse the text grammar, including the optional full word and to range word. 解析文本语法,包括可选的 full 词与区间词 to。