pub struct CallEdge {
pub caller: CallSite,
pub callee: CallSite,
}Expand description
One call edge that was observed while a CallTrace frame was active.
CallTrace 中实际观察到的一条调用边。
Fields
caller: CallSiteSite that observed the call while its frame was active. 调用发生、其帧处于活动状态的调用点。
callee: CallSiteSite recorded as the target of that call. 被记录为该调用目标的调用点。