CallTreeEdge

Struct CallTreeEdge 

pub struct CallTreeEdge {
    pub caller: usize,
    pub callee: usize,
    pub evidence: EvidenceKind,
    pub forward: bool,
}
One call relation whose two ends are both placed in the tree. 一条两端都已放置在树中的调用关系。

Fields

caller: usize

Index of the calling node. 调用方节点的下标。

callee: usize

Index of the called node. 被调用方节点的下标。

evidence: EvidenceKind

Strongest evidence supporting this relation. 支持该关系的最强证据。

forward: bool

Whether the edge runs along the drawn axis, i.e. left to right. 该边是否沿绘制轴(即从左到右)延伸。