pub struct FrameView<'a> {
pub call: &'a CallSite,
pub parent: Option<u64>,
}Expand description
A borrowed frame and its parent link, without materializing a path. 借用的调用帧及其父链接,不生成路径数组。
Fields
call: &'a CallSiteThe recorded call site. 记录下来的调用点。
parent: Option<u64>The enclosing frame id, None for a root frame.
外层调用帧 id;根帧为 None。