OwnedSourceLocation

Struct OwnedSourceLocation 

pub struct OwnedSourceLocation {
    pub file: String,
    pub line: u32,
    pub column: u32,
    pub function: String,
}
Owned declaration location used by reloadable registration faces. 可重载注册面使用的自有声明位置。

Fields

file: String

Source path recorded at the declaration site. 声明点记录的源码路径。

line: u32

One-based line number of the declaration. 声明所在的行号(从 1 开始)。

column: u32

One-based column number of the declaration. 声明所在的列号(从 1 开始)。

function: String

The registration-face handle or logical function associated with this declaration. 与该注册面声明关联的 handle 或逻辑函数名。

Implementations

Source

impl OwnedSourceLocation

pub fn portable_file(&self) -> String

The declaration’s source path with / separators on every platform. 该声明的源码路径,在任何平台上都以 / 分隔。

pub fn describe(&self) -> String

Render the source location with its logical function name. 渲染带逻辑函数名的源码位置。