pub fn parse_face(source: &str) -> Result<Option<FaceSyntax>, FaceSyntaxError>Expand description
Parse exactly one face, returning None when the file has no declaration.
解析唯一注册面;文件没有声明时返回 None。
pub fn parse_face(source: &str) -> Result<Option<FaceSyntax>, FaceSyntaxError>Parse exactly one face, returning None when the file has no declaration.
解析唯一注册面;文件没有声明时返回 None。