pub struct CallTreeEdge {
pub caller: usize,
pub callee: usize,
pub evidence: EvidenceKind,
pub forward: bool,
}Expand description
One call relation whose two ends are both placed in the tree. 一条两端都已放置在树中的调用关系。
Fields
caller: usizeIndex of the calling node. 调用方节点的下标。
callee: usizeIndex of the called node. 被调用方节点的下标。
evidence: EvidenceKindStrongest evidence supporting this relation. 支持该关系的最强证据。
forward: boolWhether the edge runs along the drawn axis, i.e. left to right. 该边是否沿绘制轴(即从左到右)延伸。